﻿using Syncfusion.SfDataGrid.XForms;
using Syncfusion.SfDataGrid.XForms.Exporting;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;

using Xamarin.Forms;

namespace SfDataGridTest
{
    class DataObject
    {
        public string Company { get; set; }
        public string Opentimes { get; set; }
        public string Address { get; set; }

        public Dictionary<string, object> Values { get; } = new Dictionary<string, object>();
    }

    public class App : Application
    {
        SfDataGrid grid;
        public App()
        {
            var company = new[] {"Company1", "Company2", "Company3" };
            var opentimes = new[] { "time 1", "time 2", "time 3, time 4" };
            var address = new[] { "address 1", " address 2", "address 3" };

            var rand = new Random();

            grid = new SfDataGrid();
            grid.AutoGenerateColumns = false;
            grid.ColumnSizer = ColumnSizer.Star;
            grid.Columns.Add(new GridTextColumn()
            {
                HeaderText = "Company",
                MappingName = "Values[company]",
                LineBreakMode = LineBreakMode.WordWrap,
                TextAlignment = TextAlignment.Start,
                HeaderTextAlignment = TextAlignment.Start
            });
            grid.Columns.Add(new GridTextColumn()
            {
                HeaderText = "Opentimes",
                MappingName = "Values[opentimes]",
                LineBreakMode = LineBreakMode.WordWrap,
                TextAlignment = TextAlignment.Start,
                HeaderTextAlignment = TextAlignment.Start
            });
            grid.Columns.Add(new GridTextColumn()
            {
                HeaderText = "Address",
                MappingName = "Values[address]",
                LineBreakMode = LineBreakMode.WordWrap,
                TextAlignment = TextAlignment.Start,
                HeaderTextAlignment = TextAlignment.Start
            });

            var data = new List<DataObject>();
            for (int i = 0; i < 1000; i++)
            {
                var obj = new DataObject();
                obj.Company = company[rand.Next(company.Length)];
                obj.Opentimes = opentimes[rand.Next(opentimes.Length)];
                obj.Address = address[rand.Next(address.Length)];
                obj.Values["company"] = obj.Company;
                obj.Values["opentimes"] = obj.Opentimes;
                obj.Values["address"] = obj.Address;
                data.Add(obj);
            }

            grid.ItemsSource = data;

            StackLayout myStack = new StackLayout();
            myStack.HorizontalOptions = LayoutOptions.FillAndExpand;

            myStack.Orientation = StackOrientation.Vertical;

            Button b = new Button();
            b.HorizontalOptions = LayoutOptions.CenterAndExpand;
            b.HeightRequest = 50;
            b.Text = "PDF";
            b.Clicked += PDF_Clicked;

            Button b1 = new Button();
            b1.HorizontalOptions = LayoutOptions.CenterAndExpand;
            b1.HeightRequest = 50;
            b1.Text = "Excel";
            b1.Clicked += Excel_Clicked;

            myStack.Children.Add(b);
            myStack.Children.Add(b1);
            myStack.Children.Add(grid);

            MainPage = new ContentPage
            {
                Content = myStack

            };
        }

        private void PDF_Clicked(object sender, EventArgs e)
        {
            DataGridPdfExportingController pdfExport = new DataGridPdfExportingController();
            MemoryStream stream = new MemoryStream();
            var doc = pdfExport.ExportToPdf(grid, new DataGridPdfExportOption()
            {
                FitAllColumnsInOnePage = true,
                ExportColumnWidth = false,
                ExportGroups = true,
                DefaultColumnWidth = 150,
                ApplyGridStyle = true,
                GridLineType = GridLineType.None,
                ExportHeader = true,
                RepeatHeaders = true
            });
            doc.Save(stream);
            doc.Close(true);

            if (Device.OS == TargetPlatform.WinPhone || Device.OS == TargetPlatform.Windows)
                Xamarin.Forms.DependencyService.Get<ISaveWindowsPhone>().Save("DataGrid.pdf", "application/pdf", stream);
            else
                Xamarin.Forms.DependencyService.Get<ISave>().Save("DataGrid.pdf", "application/pdf", stream);
        }

        private void Excel_Clicked(object sender, EventArgs e)
        {
            DataGridExcelExportingController excelExport = new DataGridExcelExportingController();
            DataGridExcelExportingOption exportOption = new DataGridExcelExportingOption() { };
            var excelEngine = excelExport.ExportToExcel(grid, exportOption);
            var workbook = excelEngine.Excel.Workbooks[0];
            MemoryStream stream = new MemoryStream();
            workbook.SaveAs(stream);
            workbook.Close();
            excelEngine.Dispose();

            if (Device.OS == TargetPlatform.WinPhone || Device.OS == TargetPlatform.Windows)
                Xamarin.Forms.DependencyService.Get<ISaveWindowsPhone>().Save("DataGrid.xlsx", "application/msexcel", stream);
            else
                Xamarin.Forms.DependencyService.Get<ISave>().Save("DataGrid.xlsx", "application/msexcel", stream);
        }

        protected override void OnStart()
        {
            // Handle when your app starts
        }

        protected override void OnSleep()
        {
            // Handle when your app sleeps
        }

        protected override void OnResume()
        {
            // Handle when your app resumes
        }
    }
}
